# PySRRegressor Reference

`PySRRegressor` has many options for controlling a symbolic regression search.
Let's look at them below.

PARAMSKEY

## PySRRegressor Functions

::: pysr.PySRRegressor.fit
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.predict
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.from_file
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.sympy
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.latex
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.pytorch
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.jax
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.latex_table
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false

::: pysr.PySRRegressor.refresh
    options:
        show_root_heading: true
        heading_level: 3
        show_root_full_path: false
